@@ -37,22 +37,25 @@ then
         chmod +x $InstP/loook.py &&
 
         mkdir -pv $InstP/locale/en/LC_MESSAGES/ &&
-        cp -av locale/en/LC_MESSAGES/loook-0.8.3.mo $InstP/locale/en/LC_MESSAGES/loook-0.8.3.mo &&
+        cp -av locale/en/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/en/LC_MESSAGES/loook-0.8.4.mo &&
 
         mkdir -pv $InstP/locale/de/LC_MESSAGES/ &&
-        cp -av locale/de/LC_MESSAGES/loook-0.8.3.mo $InstP/locale/de/LC_MESSAGES/loook-0.8.3.mo &&
+        cp -av locale/de/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/de/LC_MESSAGES/loook-0.8.4.mo &&
         
         mkdir -pv $InstP/locale/nl/LC_MESSAGES/ &&
-        cp -av locale/nl/LC_MESSAGES/loook-0.8.3.mo $InstP/locale/nl/LC_MESSAGES/loook-0.8.3.mo &&
+        cp -av locale/nl/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/nl/LC_MESSAGES/loook-0.8.4.mo &&
         
         mkdir -pv $InstP/locale/it/LC_MESSAGES/ &&
-        cp -av locale/it/LC_MESSAGES/loook-0.8.3.mo $InstP/locale/it/LC_MESSAGES/loook-0.8.3.mo &&
+        cp -av locale/it/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/it/LC_MESSAGES/loook-0.8.4.mo &&
         
         mkdir -pv $InstP/locale/cs/LC_MESSAGES/ &&
-        cp -av locale/cs/LC_MESSAGES/loook-0.8.3.mo $InstP/locale/cs/LC_MESSAGES/loook-0.8.3.mo &&
+        cp -av locale/cs/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/cs/LC_MESSAGES/loook-0.8.4.mo &&
 
         mkdir -pv $InstP/locale/es/LC_MESSAGES/ &&
-        cp -av locale/es/LC_MESSAGES/loook-0.8.3.mo $InstP/locale/es/LC_MESSAGES/loook-0.8.3.mo &&
+        cp -av locale/es/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/es/LC_MESSAGES/loook-0.8.4.mo &&
+
+        mkdir -pv $InstP/locale/fr/LC_MESSAGES/ &&
+        cp -av locale/fr/LC_MESSAGES/loook-0.8.4.mo $InstP/locale/fr/LC_MESSAGES/loook-0.8.4.mo &&
 
         ln -sv $InstP/loook.py /usr/local/bin/loook &&
 
